@@ -9,7 +9,7 @@
 #include <KSharedConfig>
 #include <QTreeWidget>
 
-#include "groupviewmodel.h"
+#include <groups/grouptreemodel.h>
 
 class QAction;
 class KActionCollection;
@@ -22,6 +22,7 @@ class View;
 class Group;
 class GroupView;
 class GroupManager;
+class TorrentGroup;
 class View;
 
 /**
@@ -40,6 +41,15 @@ public:
     /// Load status from config
     void loadState(KSharedConfigPtr cfg);
 
+    /// Get a list of all expanded groups in the tree
+    QStringList expandedGroupPaths() const;
+
+    /// Appends the group given by index if it is expanded, and recursively adds any children of index
+    void expandedGroupPaths(QStringList &groups, const QModelIndex &index) const;
+
+    /// Expand the list of groups given by their paths
+    void expandGroups(const QStringList &groupPaths);
+
     /// Create a new group
     Group *addNewGroup();
 
@@ -62,6 +72,7 @@ private Q_SLOTS:
 Q_SIGNALS:
     void currentGroupChanged(kt::Group *g);
     void openTab(Group *g);
+    void addTorrentSelectionToGroup(TorrentGroup *g);
 
 private:
     void keyPressEvent(QKeyEvent *event) override;
@@ -71,7 +82,7 @@ private:
     Core *core;
     View *view;
     GroupManager *gman;
-    GroupViewModel *model;
+    GroupTreeModel *model;
 
     QAction *open_in_new_tab;
     QAction *new_group;
