@@ -25,12 +25,11 @@ class SearchPlugin : public Plugin
 {
     Q_OBJECT
 public:
-    SearchPlugin(QObject *parent, const QVariantList &args);
+    SearchPlugin(QObject *parent, const KPluginMetaData &data, const QVariantList &args);
     ~SearchPlugin() override;
 
     void load() override;
     void unload() override;
-    bool versionCheck(const QString &version) const override;
 
     SearchEngineList *getSearchEngineList() const
     {
@@ -51,10 +50,10 @@ private Q_SLOTS:
     void preferencesUpdated();
 
 private:
-    SearchActivity *activity;
-    SearchPrefPage *pref;
-    SearchEngineList *engines;
-    ProxyHelper *proxy;
+    SearchActivity *activity = nullptr;
+    SearchPrefPage *pref = nullptr;
+    SearchEngineList *engines = nullptr;
+    ProxyHelper *proxy = nullptr;
 };
 
 }
